# TODO: Add comment
# 
# Author: jeroen
###############################################################################


setMethod("asJSON", "NULL",
	function(x, ...) {return("{}");}
);
